# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sib_api_v3_sdk.api_client import ApiClient


class SMTPApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_smtp_template(self, smtp_template, **kwargs):  # noqa: E501
        """Create a transactional email template  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_smtp_template(smtp_template, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateSmtpTemplate smtp_template: values to update in transactional email template (required)
        :return: CreateModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_smtp_template_with_http_info(smtp_template, **kwargs)  # noqa: E501
        else:
            (data) = self.create_smtp_template_with_http_info(smtp_template, **kwargs)  # noqa: E501
            return data

    def create_smtp_template_with_http_info(self, smtp_template, **kwargs):  # noqa: E501
        """Create a transactional email template  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_smtp_template_with_http_info(smtp_template, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateSmtpTemplate smtp_template: values to update in transactional email template (required)
        :return: CreateModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['smtp_template']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_smtp_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'smtp_template' is set
        if ('smtp_template' not in params or
                params['smtp_template'] is None):
            raise ValueError("Missing the required parameter `smtp_template` when calling `create_smtp_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'smtp_template' in params:
            body_params = params['smtp_template']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/templates', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_hardbounces(self, **kwargs):  # noqa: E501
        """Delete hardbounces  # noqa: E501

        Delete hardbounces. To use carefully (e.g. in case of temporary ISP failures)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_hardbounces(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteHardbounces delete_hardbounces: values to delete hardbounces
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_hardbounces_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.delete_hardbounces_with_http_info(**kwargs)  # noqa: E501
            return data

    def delete_hardbounces_with_http_info(self, **kwargs):  # noqa: E501
        """Delete hardbounces  # noqa: E501

        Delete hardbounces. To use carefully (e.g. in case of temporary ISP failures)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_hardbounces_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteHardbounces delete_hardbounces: values to delete hardbounces
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['delete_hardbounces']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_hardbounces" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_hardbounces' in params:
            body_params = params['delete_hardbounces']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/deleteHardbounces', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_smtp_template(self, template_id, **kwargs):  # noqa: E501
        """Delete an inactive transactional email template  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_smtp_template(template_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int template_id: id of the template (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_smtp_template_with_http_info(template_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_smtp_template_with_http_info(template_id, **kwargs)  # noqa: E501
            return data

    def delete_smtp_template_with_http_info(self, template_id, **kwargs):  # noqa: E501
        """Delete an inactive transactional email template  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_smtp_template_with_http_info(template_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int template_id: id of the template (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['template_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_smtp_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'template_id' is set
        if ('template_id' not in params or
                params['template_id'] is None):
            raise ValueError("Missing the required parameter `template_id` when calling `delete_smtp_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'template_id' in params:
            path_params['templateId'] = params['template_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/templates/{templateId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_aggregated_smtp_report(self, **kwargs):  # noqa: E501
        """Get your transactional email activity aggregated over a period of time  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_aggregated_smtp_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str start_date: Mandatory if endDate is used. Starting date of the report (YYYY-MM-DD). Must be lower than equal to endDate
        :param str end_date: Mandatory if startDate is used. Ending date of the report (YYYY-MM-DD). Must be greater than equal to startDate
        :param int days: Number of days in the past including today (positive integer). Not compatible with 'startDate' and 'endDate'
        :param str tag: Tag of the emails
        :return: GetAggregatedReport
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_aggregated_smtp_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_aggregated_smtp_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_aggregated_smtp_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get your transactional email activity aggregated over a period of time  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_aggregated_smtp_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str start_date: Mandatory if endDate is used. Starting date of the report (YYYY-MM-DD). Must be lower than equal to endDate
        :param str end_date: Mandatory if startDate is used. Ending date of the report (YYYY-MM-DD). Must be greater than equal to startDate
        :param int days: Number of days in the past including today (positive integer). Not compatible with 'startDate' and 'endDate'
        :param str tag: Tag of the emails
        :return: GetAggregatedReport
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_date', 'end_date', 'days', 'tag']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_aggregated_smtp_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501
        if 'days' in params:
            query_params.append(('days', params['days']))  # noqa: E501
        if 'tag' in params:
            query_params.append(('tag', params['tag']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/statistics/aggregatedReport', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAggregatedReport',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_email_event_report(self, **kwargs):  # noqa: E501
        """Get all your transactional email activity (unaggregated events)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_email_event_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Number limitation for the result returned
        :param int offset: Beginning point in the list to retrieve from.
        :param str start_date: Mandatory if endDate is used. Starting date of the report (YYYY-MM-DD). Must be lower than equal to endDate
        :param str end_date: Mandatory if startDate is used. Ending date of the report (YYYY-MM-DD). Must be greater than equal to startDate
        :param int days: Number of days in the past including today (positive integer). Not compatible with 'startDate' and 'endDate'
        :param str email: Filter the report for a specific email addresses
        :param str event: Filter the report for a specific event type
        :param str tags: Filter the report for tags (serialized and urlencoded array)
        :param str message_id: Filter on a specific message id
        :param int template_id: Filter on a specific template id
        :return: GetEmailEventReport
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_email_event_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_email_event_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_email_event_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get all your transactional email activity (unaggregated events)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_email_event_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Number limitation for the result returned
        :param int offset: Beginning point in the list to retrieve from.
        :param str start_date: Mandatory if endDate is used. Starting date of the report (YYYY-MM-DD). Must be lower than equal to endDate
        :param str end_date: Mandatory if startDate is used. Ending date of the report (YYYY-MM-DD). Must be greater than equal to startDate
        :param int days: Number of days in the past including today (positive integer). Not compatible with 'startDate' and 'endDate'
        :param str email: Filter the report for a specific email addresses
        :param str event: Filter the report for a specific event type
        :param str tags: Filter the report for tags (serialized and urlencoded array)
        :param str message_id: Filter on a specific message id
        :param int template_id: Filter on a specific template id
        :return: GetEmailEventReport
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['limit', 'offset', 'start_date', 'end_date', 'days', 'email', 'event', 'tags', 'message_id', 'template_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_email_event_report" % key
                )
            params[key] = val
        del params['kwargs']

        if 'limit' in params and params['limit'] > 100:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_email_event_report`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501
        if 'days' in params:
            query_params.append(('days', params['days']))  # noqa: E501
        if 'email' in params:
            query_params.append(('email', params['email']))  # noqa: E501
        if 'event' in params:
            query_params.append(('event', params['event']))  # noqa: E501
        if 'tags' in params:
            query_params.append(('tags', params['tags']))  # noqa: E501
        if 'message_id' in params:
            query_params.append(('messageId', params['message_id']))  # noqa: E501
        if 'template_id' in params:
            query_params.append(('templateId', params['template_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/statistics/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetEmailEventReport',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_smtp_report(self, **kwargs):  # noqa: E501
        """Get your transactional email activity aggregated per day  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_smtp_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Number of documents returned per page
        :param int offset: Index of the first document on the page
        :param str start_date: Mandatory if endDate is used. Starting date of the report (YYYY-MM-DD)
        :param str end_date: Mandatory if startDate is used. Ending date of the report (YYYY-MM-DD)
        :param int days: Number of days in the past including today (positive integer). Not compatible with 'startDate' and 'endDate'
        :param str tag: Tag of the emails
        :return: GetReports
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_smtp_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_smtp_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_smtp_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get your transactional email activity aggregated per day  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_smtp_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: Number of documents returned per page
        :param int offset: Index of the first document on the page
        :param str start_date: Mandatory if endDate is used. Starting date of the report (YYYY-MM-DD)
        :param str end_date: Mandatory if startDate is used. Ending date of the report (YYYY-MM-DD)
        :param int days: Number of days in the past including today (positive integer). Not compatible with 'startDate' and 'endDate'
        :param str tag: Tag of the emails
        :return: GetReports
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['limit', 'offset', 'start_date', 'end_date', 'days', 'tag']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_smtp_report" % key
                )
            params[key] = val
        del params['kwargs']

        if 'limit' in params and params['limit'] > 30:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_smtp_report`, must be a value less than or equal to `30`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501
        if 'days' in params:
            query_params.append(('days', params['days']))  # noqa: E501
        if 'tag' in params:
            query_params.append(('tag', params['tag']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/statistics/reports', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetReports',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_smtp_template(self, template_id, **kwargs):  # noqa: E501
        """Returns the template informations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_smtp_template(template_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int template_id: id of the template (required)
        :return: GetSmtpTemplateOverview
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_smtp_template_with_http_info(template_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_smtp_template_with_http_info(template_id, **kwargs)  # noqa: E501
            return data

    def get_smtp_template_with_http_info(self, template_id, **kwargs):  # noqa: E501
        """Returns the template informations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_smtp_template_with_http_info(template_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int template_id: id of the template (required)
        :return: GetSmtpTemplateOverview
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['template_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_smtp_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'template_id' is set
        if ('template_id' not in params or
                params['template_id'] is None):
            raise ValueError("Missing the required parameter `template_id` when calling `get_smtp_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'template_id' in params:
            path_params['templateId'] = params['template_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/templates/{templateId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSmtpTemplateOverview',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_smtp_templates(self, **kwargs):  # noqa: E501
        """Get the list of transactional email templates  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_smtp_templates(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool template_status: Filter on the status of the template. Active = true, inactive = false
        :param int limit: Number of documents returned per page
        :param int offset: Index of the first document in the page
        :return: GetSmtpTemplates
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_smtp_templates_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_smtp_templates_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_smtp_templates_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of transactional email templates  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_smtp_templates_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool template_status: Filter on the status of the template. Active = true, inactive = false
        :param int limit: Number of documents returned per page
        :param int offset: Index of the first document in the page
        :return: GetSmtpTemplates
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['template_status', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_smtp_templates" % key
                )
            params[key] = val
        del params['kwargs']

        if 'limit' in params and params['limit'] > 1000:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_smtp_templates`, must be a value less than or equal to `1000`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'template_status' in params:
            query_params.append(('templateStatus', params['template_status']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/templates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSmtpTemplates',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_transac_blocked_contacts(self, **kwargs):  # noqa: E501
        """Get the list of blocked or unsubscribed transactional contacts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_transac_blocked_contacts(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str start_date: Mandatory if endDate is used. Starting date (YYYY-MM-DD) from which you want to fetch the blocked or unsubscribed contacts
        :param str end_date: Mandatory if startDate is used. Ending date (YYYY-MM-DD) till which you want to fetch the blocked or unsubscribed contacts
        :param int limit: Number of documents returned per page
        :param int offset: Index of the first document on the page
        :param list[str] senders: Comma separated list of emails of the senders from which contacts are blocked or unsubscribed
        :return: GetTransacBlockedContacts
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_transac_blocked_contacts_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_transac_blocked_contacts_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_transac_blocked_contacts_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of blocked or unsubscribed transactional contacts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_transac_blocked_contacts_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str start_date: Mandatory if endDate is used. Starting date (YYYY-MM-DD) from which you want to fetch the blocked or unsubscribed contacts
        :param str end_date: Mandatory if startDate is used. Ending date (YYYY-MM-DD) till which you want to fetch the blocked or unsubscribed contacts
        :param int limit: Number of documents returned per page
        :param int offset: Index of the first document on the page
        :param list[str] senders: Comma separated list of emails of the senders from which contacts are blocked or unsubscribed
        :return: GetTransacBlockedContacts
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_date', 'end_date', 'limit', 'offset', 'senders']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_transac_blocked_contacts" % key
                )
            params[key] = val
        del params['kwargs']

        if 'limit' in params and params['limit'] > 100:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_transac_blocked_contacts`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'senders' in params:
            query_params.append(('senders', params['senders']))  # noqa: E501
            collection_formats['senders'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/blockedContacts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetTransacBlockedContacts',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_transac_email_content(self, uuid, **kwargs):  # noqa: E501
        """Get the personalized content of a sent transactional email  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_transac_email_content(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: Unique id of the transactional email that has been sent to a particular contact (required)
        :return: GetTransacEmailContent
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_transac_email_content_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_transac_email_content_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def get_transac_email_content_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Get the personalized content of a sent transactional email  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_transac_email_content_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: Unique id of the transactional email that has been sent to a particular contact (required)
        :return: GetTransacEmailContent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_transac_email_content" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `get_transac_email_content`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/emails/{uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetTransacEmailContent',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_transac_emails_list(self, **kwargs):  # noqa: E501
        """Get the list of transactional emails on the basis of allowed filters  # noqa: E501

        This endpoint will show the list of emails for past 30 days by default. To retrieve emails before that time, please pass startDate and endDate in query filters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_transac_emails_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: Mandatory if templateId and messageId are not passed in query filters. Email address to which transactional email has been sent.
        :param int template_id: Mandatory if email and messageId are not passed in query filters. Id of the template that was used to compose transactional email.
        :param str message_id: Mandatory if templateId and email are not passed in query filters. Message ID of the transactional email sent.
        :param str start_date: Mandatory if endDate is used. Starting date (YYYY-MM-DD) from which you want to fetch the list. Maximum time period that can be selected is one month.
        :param date end_date: Mandatory if startDate is used. Ending date (YYYY-MM-DD) till which you want to fetch the list. Maximum time period that can be selected is one month.
        :return: GetTransacEmailsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_transac_emails_list_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_transac_emails_list_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_transac_emails_list_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of transactional emails on the basis of allowed filters  # noqa: E501

        This endpoint will show the list of emails for past 30 days by default. To retrieve emails before that time, please pass startDate and endDate in query filters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_transac_emails_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: Mandatory if templateId and messageId are not passed in query filters. Email address to which transactional email has been sent.
        :param int template_id: Mandatory if email and messageId are not passed in query filters. Id of the template that was used to compose transactional email.
        :param str message_id: Mandatory if templateId and email are not passed in query filters. Message ID of the transactional email sent.
        :param str start_date: Mandatory if endDate is used. Starting date (YYYY-MM-DD) from which you want to fetch the list. Maximum time period that can be selected is one month.
        :param date end_date: Mandatory if startDate is used. Ending date (YYYY-MM-DD) till which you want to fetch the list. Maximum time period that can be selected is one month.
        :return: GetTransacEmailsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email', 'template_id', 'message_id', 'start_date', 'end_date']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_transac_emails_list" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'email' in params:
            query_params.append(('email', params['email']))  # noqa: E501
        if 'template_id' in params:
            query_params.append(('templateId', params['template_id']))  # noqa: E501
        if 'message_id' in params:
            query_params.append(('messageId', params['message_id']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/emails', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetTransacEmailsList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_template(self, template_id, send_email, **kwargs):  # noqa: E501
        """Send a template  # noqa: E501

        This endpoint is deprecated. Prefer v3/smtp/email instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_template(template_id, send_email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int template_id: Id of the template (required)
        :param SendEmail send_email: (required)
        :return: SendTemplateEmail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_template_with_http_info(template_id, send_email, **kwargs)  # noqa: E501
        else:
            (data) = self.send_template_with_http_info(template_id, send_email, **kwargs)  # noqa: E501
            return data

    def send_template_with_http_info(self, template_id, send_email, **kwargs):  # noqa: E501
        """Send a template  # noqa: E501

        This endpoint is deprecated. Prefer v3/smtp/email instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_template_with_http_info(template_id, send_email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int template_id: Id of the template (required)
        :param SendEmail send_email: (required)
        :return: SendTemplateEmail
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['template_id', 'send_email']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'template_id' is set
        if ('template_id' not in params or
                params['template_id'] is None):
            raise ValueError("Missing the required parameter `template_id` when calling `send_template`")  # noqa: E501
        # verify the required parameter 'send_email' is set
        if ('send_email' not in params or
                params['send_email'] is None):
            raise ValueError("Missing the required parameter `send_email` when calling `send_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'template_id' in params:
            path_params['templateId'] = params['template_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'send_email' in params:
            body_params = params['send_email']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/templates/{templateId}/send', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SendTemplateEmail',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_test_template(self, template_id, send_test_email, **kwargs):  # noqa: E501
        """Send a template to your test list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_test_template(template_id, send_test_email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int template_id: Id of the template (required)
        :param SendTestEmail send_test_email: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_test_template_with_http_info(template_id, send_test_email, **kwargs)  # noqa: E501
        else:
            (data) = self.send_test_template_with_http_info(template_id, send_test_email, **kwargs)  # noqa: E501
            return data

    def send_test_template_with_http_info(self, template_id, send_test_email, **kwargs):  # noqa: E501
        """Send a template to your test list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_test_template_with_http_info(template_id, send_test_email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int template_id: Id of the template (required)
        :param SendTestEmail send_test_email: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['template_id', 'send_test_email']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_test_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'template_id' is set
        if ('template_id' not in params or
                params['template_id'] is None):
            raise ValueError("Missing the required parameter `template_id` when calling `send_test_template`")  # noqa: E501
        # verify the required parameter 'send_test_email' is set
        if ('send_test_email' not in params or
                params['send_test_email'] is None):
            raise ValueError("Missing the required parameter `send_test_email` when calling `send_test_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'template_id' in params:
            path_params['templateId'] = params['template_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'send_test_email' in params:
            body_params = params['send_test_email']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/templates/{templateId}/sendTest', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_transac_email(self, send_smtp_email, **kwargs):  # noqa: E501
        """Send a transactional email  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_transac_email(send_smtp_email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SendSmtpEmail send_smtp_email: Values to send a transactional email (required)
        :return: CreateSmtpEmail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_transac_email_with_http_info(send_smtp_email, **kwargs)  # noqa: E501
        else:
            (data) = self.send_transac_email_with_http_info(send_smtp_email, **kwargs)  # noqa: E501
            return data

    def send_transac_email_with_http_info(self, send_smtp_email, **kwargs):  # noqa: E501
        """Send a transactional email  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_transac_email_with_http_info(send_smtp_email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SendSmtpEmail send_smtp_email: Values to send a transactional email (required)
        :return: CreateSmtpEmail
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['send_smtp_email']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_transac_email" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'send_smtp_email' is set
        if ('send_smtp_email' not in params or
                params['send_smtp_email'] is None):
            raise ValueError("Missing the required parameter `send_smtp_email` when calling `send_transac_email`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'send_smtp_email' in params:
            body_params = params['send_smtp_email']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/email', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateSmtpEmail',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def smtp_blocked_contacts_email_delete(self, email, **kwargs):  # noqa: E501
        """Unblock or resubscribe a transactional contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.smtp_blocked_contacts_email_delete(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: contact email (urlencoded) to unblock. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.smtp_blocked_contacts_email_delete_with_http_info(email, **kwargs)  # noqa: E501
        else:
            (data) = self.smtp_blocked_contacts_email_delete_with_http_info(email, **kwargs)  # noqa: E501
            return data

    def smtp_blocked_contacts_email_delete_with_http_info(self, email, **kwargs):  # noqa: E501
        """Unblock or resubscribe a transactional contact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.smtp_blocked_contacts_email_delete_with_http_info(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: contact email (urlencoded) to unblock. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method smtp_blocked_contacts_email_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email' is set
        if ('email' not in params or
                params['email'] is None):
            raise ValueError("Missing the required parameter `email` when calling `smtp_blocked_contacts_email_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'email' in params:
            path_params['email'] = params['email']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/blockedContacts/{email}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def smtp_log_message_id_delete(self, message_id, **kwargs):  # noqa: E501
        """Delete an SMTP transactional log  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.smtp_log_message_id_delete(message_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str message_id: MessageId of the transactional log to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.smtp_log_message_id_delete_with_http_info(message_id, **kwargs)  # noqa: E501
        else:
            (data) = self.smtp_log_message_id_delete_with_http_info(message_id, **kwargs)  # noqa: E501
            return data

    def smtp_log_message_id_delete_with_http_info(self, message_id, **kwargs):  # noqa: E501
        """Delete an SMTP transactional log  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.smtp_log_message_id_delete_with_http_info(message_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str message_id: MessageId of the transactional log to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['message_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method smtp_log_message_id_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'message_id' is set
        if ('message_id' not in params or
                params['message_id'] is None):
            raise ValueError("Missing the required parameter `message_id` when calling `smtp_log_message_id_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'message_id' in params:
            path_params['messageId'] = params['message_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/log/{messageId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_smtp_template(self, template_id, smtp_template, **kwargs):  # noqa: E501
        """Updates a transactional email templates  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_smtp_template(template_id, smtp_template, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int template_id: id of the template (required)
        :param UpdateSmtpTemplate smtp_template: values to update in transactional email template (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_smtp_template_with_http_info(template_id, smtp_template, **kwargs)  # noqa: E501
        else:
            (data) = self.update_smtp_template_with_http_info(template_id, smtp_template, **kwargs)  # noqa: E501
            return data

    def update_smtp_template_with_http_info(self, template_id, smtp_template, **kwargs):  # noqa: E501
        """Updates a transactional email templates  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_smtp_template_with_http_info(template_id, smtp_template, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int template_id: id of the template (required)
        :param UpdateSmtpTemplate smtp_template: values to update in transactional email template (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['template_id', 'smtp_template']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_smtp_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'template_id' is set
        if ('template_id' not in params or
                params['template_id'] is None):
            raise ValueError("Missing the required parameter `template_id` when calling `update_smtp_template`")  # noqa: E501
        # verify the required parameter 'smtp_template' is set
        if ('smtp_template' not in params or
                params['smtp_template'] is None):
            raise ValueError("Missing the required parameter `smtp_template` when calling `update_smtp_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'template_id' in params:
            path_params['templateId'] = params['template_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'smtp_template' in params:
            body_params = params['smtp_template']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/smtp/templates/{templateId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetSharedTemplateUrl(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'shared_url': 'str'
    }

    attribute_map = {
        'shared_url': 'sharedUrl'
    }

    def __init__(self, shared_url=None):  # noqa: E501
        """GetSharedTemplateUrl - a model defined in Swagger"""  # noqa: E501

        self._shared_url = None
        self.discriminator = None

        self.shared_url = shared_url

    @property
    def shared_url(self):
        """Gets the shared_url of this GetSharedTemplateUrl.  # noqa: E501

        A unique URL for the email campaign or transactional template. This URL can be shared with other Sendinblue users.  # noqa: E501

        :return: The shared_url of this GetSharedTemplateUrl.  # noqa: E501
        :rtype: str
        """
        return self._shared_url

    @shared_url.setter
    def shared_url(self, shared_url):
        """Sets the shared_url of this GetSharedTemplateUrl.

        A unique URL for the email campaign or transactional template. This URL can be shared with other Sendinblue users.  # noqa: E501

        :param shared_url: The shared_url of this GetSharedTemplateUrl.  # noqa: E501
        :type: str
        """
        if shared_url is None:
            raise ValueError("Invalid value for `shared_url`, must not be `None`")  # noqa: E501

        self._shared_url = shared_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetSharedTemplateUrl, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetSharedTemplateUrl):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CreateSmsCampaign(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'sender': 'str',
        'content': 'str',
        'recipients': 'CreateSmsCampaignRecipients',
        'scheduled_at': 'datetime'
    }

    attribute_map = {
        'name': 'name',
        'sender': 'sender',
        'content': 'content',
        'recipients': 'recipients',
        'scheduled_at': 'scheduledAt'
    }

    def __init__(self, name=None, sender=None, content=None, recipients=None, scheduled_at=None):  # noqa: E501
        """CreateSmsCampaign - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._sender = None
        self._content = None
        self._recipients = None
        self._scheduled_at = None
        self.discriminator = None

        self.name = name
        self.sender = sender
        self.content = content
        if recipients is not None:
            self.recipients = recipients
        if scheduled_at is not None:
            self.scheduled_at = scheduled_at

    @property
    def name(self):
        """Gets the name of this CreateSmsCampaign.  # noqa: E501

        Name of the campaign  # noqa: E501

        :return: The name of this CreateSmsCampaign.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateSmsCampaign.

        Name of the campaign  # noqa: E501

        :param name: The name of this CreateSmsCampaign.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def sender(self):
        """Gets the sender of this CreateSmsCampaign.  # noqa: E501

        Name of the sender. The number of characters is limited to 11  # noqa: E501

        :return: The sender of this CreateSmsCampaign.  # noqa: E501
        :rtype: str
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this CreateSmsCampaign.

        Name of the sender. The number of characters is limited to 11  # noqa: E501

        :param sender: The sender of this CreateSmsCampaign.  # noqa: E501
        :type: str
        """
        if sender is None:
            raise ValueError("Invalid value for `sender`, must not be `None`")  # noqa: E501
        if sender is not None and len(sender) > 11:
            raise ValueError("Invalid value for `sender`, length must be less than or equal to `11`")  # noqa: E501

        self._sender = sender

    @property
    def content(self):
        """Gets the content of this CreateSmsCampaign.  # noqa: E501

        Content of the message. The maximum characters used per SMS is 160, if used more than that, it will be counted as more than one SMS  # noqa: E501

        :return: The content of this CreateSmsCampaign.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this CreateSmsCampaign.

        Content of the message. The maximum characters used per SMS is 160, if used more than that, it will be counted as more than one SMS  # noqa: E501

        :param content: The content of this CreateSmsCampaign.  # noqa: E501
        :type: str
        """
        if content is None:
            raise ValueError("Invalid value for `content`, must not be `None`")  # noqa: E501

        self._content = content

    @property
    def recipients(self):
        """Gets the recipients of this CreateSmsCampaign.  # noqa: E501


        :return: The recipients of this CreateSmsCampaign.  # noqa: E501
        :rtype: CreateSmsCampaignRecipients
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this CreateSmsCampaign.


        :param recipients: The recipients of this CreateSmsCampaign.  # noqa: E501
        :type: CreateSmsCampaignRecipients
        """

        self._recipients = recipients

    @property
    def scheduled_at(self):
        """Gets the scheduled_at of this CreateSmsCampaign.  # noqa: E501

        UTC date-time on which the campaign has to run (YYYY-MM-DDTHH:mm:ss.SSSZ). Prefer to pass your timezone in date-time format for accurate result.  # noqa: E501

        :return: The scheduled_at of this CreateSmsCampaign.  # noqa: E501
        :rtype: datetime
        """
        return self._scheduled_at

    @scheduled_at.setter
    def scheduled_at(self, scheduled_at):
        """Sets the scheduled_at of this CreateSmsCampaign.

        UTC date-time on which the campaign has to run (YYYY-MM-DDTHH:mm:ss.SSSZ). Prefer to pass your timezone in date-time format for accurate result.  # noqa: E501

        :param scheduled_at: The scheduled_at of this CreateSmsCampaign.  # noqa: E501
        :type: datetime
        """

        self._scheduled_at = scheduled_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateSmsCampaign, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateSmsCampaign):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CreateContact(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'attributes': 'object',
        'email_blacklisted': 'bool',
        'sms_blacklisted': 'bool',
        'list_ids': 'list[int]',
        'update_enabled': 'bool',
        'smtp_blacklist_sender': 'list[str]'
    }

    attribute_map = {
        'email': 'email',
        'attributes': 'attributes',
        'email_blacklisted': 'emailBlacklisted',
        'sms_blacklisted': 'smsBlacklisted',
        'list_ids': 'listIds',
        'update_enabled': 'updateEnabled',
        'smtp_blacklist_sender': 'smtpBlacklistSender'
    }

    def __init__(self, email=None, attributes=None, email_blacklisted=None, sms_blacklisted=None, list_ids=None, update_enabled=False, smtp_blacklist_sender=None):  # noqa: E501
        """CreateContact - a model defined in Swagger"""  # noqa: E501

        self._email = None
        self._attributes = None
        self._email_blacklisted = None
        self._sms_blacklisted = None
        self._list_ids = None
        self._update_enabled = None
        self._smtp_blacklist_sender = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if attributes is not None:
            self.attributes = attributes
        if email_blacklisted is not None:
            self.email_blacklisted = email_blacklisted
        if sms_blacklisted is not None:
            self.sms_blacklisted = sms_blacklisted
        if list_ids is not None:
            self.list_ids = list_ids
        if update_enabled is not None:
            self.update_enabled = update_enabled
        if smtp_blacklist_sender is not None:
            self.smtp_blacklist_sender = smtp_blacklist_sender

    @property
    def email(self):
        """Gets the email of this CreateContact.  # noqa: E501

        Email address of the user. Mandatory if \"SMS\" field is not passed in \"attributes\" parameter. Mobile Number in \"SMS\" field should be passed with proper country code. For example {'SMS':'+91xxxxxxxxxx'} or {'SMS':'0091xxxxxxxxxx'}  # noqa: E501

        :return: The email of this CreateContact.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this CreateContact.

        Email address of the user. Mandatory if \"SMS\" field is not passed in \"attributes\" parameter. Mobile Number in \"SMS\" field should be passed with proper country code. For example {'SMS':'+91xxxxxxxxxx'} or {'SMS':'0091xxxxxxxxxx'}  # noqa: E501

        :param email: The email of this CreateContact.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def attributes(self):
        """Gets the attributes of this CreateContact.  # noqa: E501

        Pass the set of attributes and their values. These attributes must be present in your SendinBlue account. For eg. {'FNAME':'Elly', 'LNAME':'Roger'}  # noqa: E501

        :return: The attributes of this CreateContact.  # noqa: E501
        :rtype: object
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this CreateContact.

        Pass the set of attributes and their values. These attributes must be present in your SendinBlue account. For eg. {'FNAME':'Elly', 'LNAME':'Roger'}  # noqa: E501

        :param attributes: The attributes of this CreateContact.  # noqa: E501
        :type: object
        """

        self._attributes = attributes

    @property
    def email_blacklisted(self):
        """Gets the email_blacklisted of this CreateContact.  # noqa: E501

        Set this field to blacklist the contact for emails (emailBlacklisted = true)  # noqa: E501

        :return: The email_blacklisted of this CreateContact.  # noqa: E501
        :rtype: bool
        """
        return self._email_blacklisted

    @email_blacklisted.setter
    def email_blacklisted(self, email_blacklisted):
        """Sets the email_blacklisted of this CreateContact.

        Set this field to blacklist the contact for emails (emailBlacklisted = true)  # noqa: E501

        :param email_blacklisted: The email_blacklisted of this CreateContact.  # noqa: E501
        :type: bool
        """

        self._email_blacklisted = email_blacklisted

    @property
    def sms_blacklisted(self):
        """Gets the sms_blacklisted of this CreateContact.  # noqa: E501

        Set this field to blacklist the contact for SMS (smsBlacklisted = true)  # noqa: E501

        :return: The sms_blacklisted of this CreateContact.  # noqa: E501
        :rtype: bool
        """
        return self._sms_blacklisted

    @sms_blacklisted.setter
    def sms_blacklisted(self, sms_blacklisted):
        """Sets the sms_blacklisted of this CreateContact.

        Set this field to blacklist the contact for SMS (smsBlacklisted = true)  # noqa: E501

        :param sms_blacklisted: The sms_blacklisted of this CreateContact.  # noqa: E501
        :type: bool
        """

        self._sms_blacklisted = sms_blacklisted

    @property
    def list_ids(self):
        """Gets the list_ids of this CreateContact.  # noqa: E501

        Ids of the lists to add the contact to  # noqa: E501

        :return: The list_ids of this CreateContact.  # noqa: E501
        :rtype: list[int]
        """
        return self._list_ids

    @list_ids.setter
    def list_ids(self, list_ids):
        """Sets the list_ids of this CreateContact.

        Ids of the lists to add the contact to  # noqa: E501

        :param list_ids: The list_ids of this CreateContact.  # noqa: E501
        :type: list[int]
        """

        self._list_ids = list_ids

    @property
    def update_enabled(self):
        """Gets the update_enabled of this CreateContact.  # noqa: E501

        Facilitate to update the existing contact in the same request (updateEnabled = true)  # noqa: E501

        :return: The update_enabled of this CreateContact.  # noqa: E501
        :rtype: bool
        """
        return self._update_enabled

    @update_enabled.setter
    def update_enabled(self, update_enabled):
        """Sets the update_enabled of this CreateContact.

        Facilitate to update the existing contact in the same request (updateEnabled = true)  # noqa: E501

        :param update_enabled: The update_enabled of this CreateContact.  # noqa: E501
        :type: bool
        """

        self._update_enabled = update_enabled

    @property
    def smtp_blacklist_sender(self):
        """Gets the smtp_blacklist_sender of this CreateContact.  # noqa: E501

        transactional email forbidden sender for contact. Use only for email Contact ( only available if updateEnabled = true )  # noqa: E501

        :return: The smtp_blacklist_sender of this CreateContact.  # noqa: E501
        :rtype: list[str]
        """
        return self._smtp_blacklist_sender

    @smtp_blacklist_sender.setter
    def smtp_blacklist_sender(self, smtp_blacklist_sender):
        """Sets the smtp_blacklist_sender of this CreateContact.

        transactional email forbidden sender for contact. Use only for email Contact ( only available if updateEnabled = true )  # noqa: E501

        :param smtp_blacklist_sender: The smtp_blacklist_sender of this CreateContact.  # noqa: E501
        :type: list[str]
        """

        self._smtp_blacklist_sender = smtp_blacklist_sender

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateContact, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateContact):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from sib_api_v3_sdk.models.ab_test_campaign_result import AbTestCampaignResult
from sib_api_v3_sdk.models.add_child_domain import AddChildDomain
from sib_api_v3_sdk.models.add_contact_to_list import AddContactToList
from sib_api_v3_sdk.models.add_credits import AddCredits
from sib_api_v3_sdk.models.create_attribute import CreateAttribute
from sib_api_v3_sdk.models.create_attribute_enumeration import CreateAttributeEnumeration
from sib_api_v3_sdk.models.create_child import CreateChild
from sib_api_v3_sdk.models.create_contact import CreateContact
from sib_api_v3_sdk.models.create_email_campaign import CreateEmailCampaign
from sib_api_v3_sdk.models.create_email_campaign_recipients import CreateEmailCampaignRecipients
from sib_api_v3_sdk.models.create_email_campaign_sender import CreateEmailCampaignSender
from sib_api_v3_sdk.models.create_list import CreateList
from sib_api_v3_sdk.models.create_model import CreateModel
from sib_api_v3_sdk.models.create_reseller import CreateReseller
from sib_api_v3_sdk.models.create_sender import CreateSender
from sib_api_v3_sdk.models.create_sender_ips import CreateSenderIps
from sib_api_v3_sdk.models.create_sender_model import CreateSenderModel
from sib_api_v3_sdk.models.create_sms_campaign import CreateSmsCampaign
from sib_api_v3_sdk.models.create_sms_campaign_recipients import CreateSmsCampaignRecipients
from sib_api_v3_sdk.models.create_smtp_email import CreateSmtpEmail
from sib_api_v3_sdk.models.create_smtp_template import CreateSmtpTemplate
from sib_api_v3_sdk.models.create_smtp_template_sender import CreateSmtpTemplateSender
from sib_api_v3_sdk.models.create_update_contact_model import CreateUpdateContactModel
from sib_api_v3_sdk.models.create_update_folder import CreateUpdateFolder
from sib_api_v3_sdk.models.create_webhook import CreateWebhook
from sib_api_v3_sdk.models.created_process_id import CreatedProcessId
from sib_api_v3_sdk.models.delete_hardbounces import DeleteHardbounces
from sib_api_v3_sdk.models.email_export_recipients import EmailExportRecipients
from sib_api_v3_sdk.models.error_model import ErrorModel
from sib_api_v3_sdk.models.get_account_marketing_automation import GetAccountMarketingAutomation
from sib_api_v3_sdk.models.get_account_plan import GetAccountPlan
from sib_api_v3_sdk.models.get_account_relay import GetAccountRelay
from sib_api_v3_sdk.models.get_account_relay_data import GetAccountRelayData
from sib_api_v3_sdk.models.get_aggregated_report import GetAggregatedReport
from sib_api_v3_sdk.models.get_attributes import GetAttributes
from sib_api_v3_sdk.models.get_attributes_attributes import GetAttributesAttributes
from sib_api_v3_sdk.models.get_attributes_enumeration import GetAttributesEnumeration
from sib_api_v3_sdk.models.get_campaign_overview import GetCampaignOverview
from sib_api_v3_sdk.models.get_campaign_recipients import GetCampaignRecipients
from sib_api_v3_sdk.models.get_campaign_stats import GetCampaignStats
from sib_api_v3_sdk.models.get_child_account_creation_status import GetChildAccountCreationStatus
from sib_api_v3_sdk.models.get_child_domain import GetChildDomain
from sib_api_v3_sdk.models.get_child_domains import GetChildDomains
from sib_api_v3_sdk.models.get_child_info_api_keys import GetChildInfoApiKeys
from sib_api_v3_sdk.models.get_child_info_api_keys_v2 import GetChildInfoApiKeysV2
from sib_api_v3_sdk.models.get_child_info_api_keys_v3 import GetChildInfoApiKeysV3
from sib_api_v3_sdk.models.get_child_info_credits import GetChildInfoCredits
from sib_api_v3_sdk.models.get_child_info_statistics import GetChildInfoStatistics
from sib_api_v3_sdk.models.get_children_list import GetChildrenList
from sib_api_v3_sdk.models.get_client import GetClient
from sib_api_v3_sdk.models.get_contact_campaign_stats import GetContactCampaignStats
from sib_api_v3_sdk.models.get_contact_campaign_stats_clicked import GetContactCampaignStatsClicked
from sib_api_v3_sdk.models.get_contact_campaign_stats_opened import GetContactCampaignStatsOpened
from sib_api_v3_sdk.models.get_contact_campaign_stats_transac_attributes import GetContactCampaignStatsTransacAttributes
from sib_api_v3_sdk.models.get_contact_campaign_stats_unsubscriptions import GetContactCampaignStatsUnsubscriptions
from sib_api_v3_sdk.models.get_contact_details import GetContactDetails
from sib_api_v3_sdk.models.get_contacts import GetContacts
from sib_api_v3_sdk.models.get_device_browser_stats import GetDeviceBrowserStats
from sib_api_v3_sdk.models.get_email_campaigns import GetEmailCampaigns
from sib_api_v3_sdk.models.get_email_event_report import GetEmailEventReport
from sib_api_v3_sdk.models.get_email_event_report_events import GetEmailEventReportEvents
from sib_api_v3_sdk.models.get_extended_campaign_overview_sender import GetExtendedCampaignOverviewSender
from sib_api_v3_sdk.models.get_extended_campaign_stats import GetExtendedCampaignStats
from sib_api_v3_sdk.models.get_extended_client_address import GetExtendedClientAddress
from sib_api_v3_sdk.models.get_extended_contact_details_statistics import GetExtendedContactDetailsStatistics
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_clicked import GetExtendedContactDetailsStatisticsClicked
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_links import GetExtendedContactDetailsStatisticsLinks
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_messages_sent import GetExtendedContactDetailsStatisticsMessagesSent
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_opened import GetExtendedContactDetailsStatisticsOpened
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_unsubscriptions import GetExtendedContactDetailsStatisticsUnsubscriptions
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_unsubscriptions_admin_unsubscription import GetExtendedContactDetailsStatisticsUnsubscriptionsAdminUnsubscription
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_unsubscriptions_user_unsubscription import GetExtendedContactDetailsStatisticsUnsubscriptionsUserUnsubscription
from sib_api_v3_sdk.models.get_extended_list_campaign_stats import GetExtendedListCampaignStats
from sib_api_v3_sdk.models.get_folder import GetFolder
from sib_api_v3_sdk.models.get_folder_lists import GetFolderLists
from sib_api_v3_sdk.models.get_folders import GetFolders
from sib_api_v3_sdk.models.get_ip import GetIp
from sib_api_v3_sdk.models.get_ip_from_sender import GetIpFromSender
from sib_api_v3_sdk.models.get_ips import GetIps
from sib_api_v3_sdk.models.get_ips_from_sender import GetIpsFromSender
from sib_api_v3_sdk.models.get_list import GetList
from sib_api_v3_sdk.models.get_lists import GetLists
from sib_api_v3_sdk.models.get_process import GetProcess
from sib_api_v3_sdk.models.get_processes import GetProcesses
from sib_api_v3_sdk.models.get_reports import GetReports
from sib_api_v3_sdk.models.get_reports_reports import GetReportsReports
from sib_api_v3_sdk.models.get_senders_list import GetSendersList
from sib_api_v3_sdk.models.get_senders_list_ips import GetSendersListIps
from sib_api_v3_sdk.models.get_senders_list_senders import GetSendersListSenders
from sib_api_v3_sdk.models.get_shared_template_url import GetSharedTemplateUrl
from sib_api_v3_sdk.models.get_sms_campaign_overview import GetSmsCampaignOverview
from sib_api_v3_sdk.models.get_sms_campaign_stats import GetSmsCampaignStats
from sib_api_v3_sdk.models.get_sms_campaigns import GetSmsCampaigns
from sib_api_v3_sdk.models.get_sms_event_report import GetSmsEventReport
from sib_api_v3_sdk.models.get_sms_event_report_events import GetSmsEventReportEvents
from sib_api_v3_sdk.models.get_smtp_template_overview import GetSmtpTemplateOverview
from sib_api_v3_sdk.models.get_smtp_template_overview_sender import GetSmtpTemplateOverviewSender
from sib_api_v3_sdk.models.get_smtp_templates import GetSmtpTemplates
from sib_api_v3_sdk.models.get_sso_token import GetSsoToken
from sib_api_v3_sdk.models.get_stats_by_browser import GetStatsByBrowser
from sib_api_v3_sdk.models.get_stats_by_device import GetStatsByDevice
from sib_api_v3_sdk.models.get_stats_by_domain import GetStatsByDomain
from sib_api_v3_sdk.models.get_transac_aggregated_sms_report import GetTransacAggregatedSmsReport
from sib_api_v3_sdk.models.get_transac_blocked_contacts import GetTransacBlockedContacts
from sib_api_v3_sdk.models.get_transac_blocked_contacts_contacts import GetTransacBlockedContactsContacts
from sib_api_v3_sdk.models.get_transac_blocked_contacts_reason import GetTransacBlockedContactsReason
from sib_api_v3_sdk.models.get_transac_email_content import GetTransacEmailContent
from sib_api_v3_sdk.models.get_transac_email_content_events import GetTransacEmailContentEvents
from sib_api_v3_sdk.models.get_transac_emails_list import GetTransacEmailsList
from sib_api_v3_sdk.models.get_transac_emails_list_transactional_emails import GetTransacEmailsListTransactionalEmails
from sib_api_v3_sdk.models.get_transac_sms_report import GetTransacSmsReport
from sib_api_v3_sdk.models.get_transac_sms_report_reports import GetTransacSmsReportReports
from sib_api_v3_sdk.models.get_webhook import GetWebhook
from sib_api_v3_sdk.models.get_webhooks import GetWebhooks
from sib_api_v3_sdk.models.manage_ip import ManageIp
from sib_api_v3_sdk.models.post_contact_info import PostContactInfo
from sib_api_v3_sdk.models.post_contact_info_contacts import PostContactInfoContacts
from sib_api_v3_sdk.models.post_send_failed import PostSendFailed
from sib_api_v3_sdk.models.post_send_sms_test_failed import PostSendSmsTestFailed
from sib_api_v3_sdk.models.remaining_credit_model import RemainingCreditModel
from sib_api_v3_sdk.models.remaining_credit_model_child import RemainingCreditModelChild
from sib_api_v3_sdk.models.remaining_credit_model_reseller import RemainingCreditModelReseller
from sib_api_v3_sdk.models.remove_contact_from_list import RemoveContactFromList
from sib_api_v3_sdk.models.remove_credits import RemoveCredits
from sib_api_v3_sdk.models.request_contact_export import RequestContactExport
from sib_api_v3_sdk.models.request_contact_export_custom_contact_filter import RequestContactExportCustomContactFilter
from sib_api_v3_sdk.models.request_contact_import import RequestContactImport
from sib_api_v3_sdk.models.request_contact_import_new_list import RequestContactImportNewList
from sib_api_v3_sdk.models.request_sms_recipient_export import RequestSmsRecipientExport
from sib_api_v3_sdk.models.send_email import SendEmail
from sib_api_v3_sdk.models.send_email_attachment import SendEmailAttachment
from sib_api_v3_sdk.models.send_report import SendReport
from sib_api_v3_sdk.models.send_report_email import SendReportEmail
from sib_api_v3_sdk.models.send_sms import SendSms
from sib_api_v3_sdk.models.send_smtp_email import SendSmtpEmail
from sib_api_v3_sdk.models.send_smtp_email_attachment import SendSmtpEmailAttachment
from sib_api_v3_sdk.models.send_smtp_email_bcc import SendSmtpEmailBcc
from sib_api_v3_sdk.models.send_smtp_email_cc import SendSmtpEmailCc
from sib_api_v3_sdk.models.send_smtp_email_reply_to import SendSmtpEmailReplyTo
from sib_api_v3_sdk.models.send_smtp_email_sender import SendSmtpEmailSender
from sib_api_v3_sdk.models.send_smtp_email_to import SendSmtpEmailTo
from sib_api_v3_sdk.models.send_template_email import SendTemplateEmail
from sib_api_v3_sdk.models.send_test_email import SendTestEmail
from sib_api_v3_sdk.models.send_test_sms import SendTestSms
from sib_api_v3_sdk.models.send_transac_sms import SendTransacSms
from sib_api_v3_sdk.models.update_attribute import UpdateAttribute
from sib_api_v3_sdk.models.update_attribute_enumeration import UpdateAttributeEnumeration
from sib_api_v3_sdk.models.update_campaign_status import UpdateCampaignStatus
from sib_api_v3_sdk.models.update_child import UpdateChild
from sib_api_v3_sdk.models.update_child_account_status import UpdateChildAccountStatus
from sib_api_v3_sdk.models.update_child_domain import UpdateChildDomain
from sib_api_v3_sdk.models.update_contact import UpdateContact
from sib_api_v3_sdk.models.update_email_campaign import UpdateEmailCampaign
from sib_api_v3_sdk.models.update_email_campaign_recipients import UpdateEmailCampaignRecipients
from sib_api_v3_sdk.models.update_email_campaign_sender import UpdateEmailCampaignSender
from sib_api_v3_sdk.models.update_list import UpdateList
from sib_api_v3_sdk.models.update_sender import UpdateSender
from sib_api_v3_sdk.models.update_sms_campaign import UpdateSmsCampaign
from sib_api_v3_sdk.models.update_smtp_template import UpdateSmtpTemplate
from sib_api_v3_sdk.models.update_smtp_template_sender import UpdateSmtpTemplateSender
from sib_api_v3_sdk.models.update_webhook import UpdateWebhook
from sib_api_v3_sdk.models.get_child_info import GetChildInfo
from sib_api_v3_sdk.models.get_extended_campaign_overview import GetExtendedCampaignOverview
from sib_api_v3_sdk.models.get_extended_client import GetExtendedClient
from sib_api_v3_sdk.models.get_extended_contact_details import GetExtendedContactDetails
from sib_api_v3_sdk.models.get_extended_list import GetExtendedList
from sib_api_v3_sdk.models.get_sms_campaign import GetSmsCampaign
from sib_api_v3_sdk.models.get_account import GetAccount
from sib_api_v3_sdk.models.get_email_campaign import GetEmailCampaign



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RequestContactExportCustomContactFilter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'action_for_contacts': 'str',
        'action_for_email_campaigns': 'str',
        'action_for_sms_campaigns': 'str',
        'list_id': 'int',
        'email_campaign_id': 'int',
        'sms_campaign_id': 'int'
    }

    attribute_map = {
        'action_for_contacts': 'actionForContacts',
        'action_for_email_campaigns': 'actionForEmailCampaigns',
        'action_for_sms_campaigns': 'actionForSmsCampaigns',
        'list_id': 'listId',
        'email_campaign_id': 'emailCampaignId',
        'sms_campaign_id': 'smsCampaignId'
    }

    def __init__(self, action_for_contacts=None, action_for_email_campaigns=None, action_for_sms_campaigns=None, list_id=None, email_campaign_id=None, sms_campaign_id=None):  # noqa: E501
        """RequestContactExportCustomContactFilter - a model defined in Swagger"""  # noqa: E501

        self._action_for_contacts = None
        self._action_for_email_campaigns = None
        self._action_for_sms_campaigns = None
        self._list_id = None
        self._email_campaign_id = None
        self._sms_campaign_id = None
        self.discriminator = None

        if action_for_contacts is not None:
            self.action_for_contacts = action_for_contacts
        if action_for_email_campaigns is not None:
            self.action_for_email_campaigns = action_for_email_campaigns
        if action_for_sms_campaigns is not None:
            self.action_for_sms_campaigns = action_for_sms_campaigns
        if list_id is not None:
            self.list_id = list_id
        if email_campaign_id is not None:
            self.email_campaign_id = email_campaign_id
        if sms_campaign_id is not None:
            self.sms_campaign_id = sms_campaign_id

    @property
    def action_for_contacts(self):
        """Gets the action_for_contacts of this RequestContactExportCustomContactFilter.  # noqa: E501

        Mandatory if neither actionForEmailCampaigns nor actionForSmsCampaigns is passed. This will export the contacts on the basis of provided action applied on contacts as per the list id. * allContacts - Fetch the list of all contacts for a particular list. * subscribed & unsubscribed - Fetch the list of subscribed / unsubscribed (blacklisted via any means) contacts for a particular list. * unsubscribedPerList - Fetch the list of contacts that are unsubscribed from a particular list only.   # noqa: E501

        :return: The action_for_contacts of this RequestContactExportCustomContactFilter.  # noqa: E501
        :rtype: str
        """
        return self._action_for_contacts

    @action_for_contacts.setter
    def action_for_contacts(self, action_for_contacts):
        """Sets the action_for_contacts of this RequestContactExportCustomContactFilter.

        Mandatory if neither actionForEmailCampaigns nor actionForSmsCampaigns is passed. This will export the contacts on the basis of provided action applied on contacts as per the list id. * allContacts - Fetch the list of all contacts for a particular list. * subscribed & unsubscribed - Fetch the list of subscribed / unsubscribed (blacklisted via any means) contacts for a particular list. * unsubscribedPerList - Fetch the list of contacts that are unsubscribed from a particular list only.   # noqa: E501

        :param action_for_contacts: The action_for_contacts of this RequestContactExportCustomContactFilter.  # noqa: E501
        :type: str
        """
        allowed_values = ["allContacts", "subscribed", "unsubscribed", "unsubscribedPerList"]  # noqa: E501
        if action_for_contacts not in allowed_values:
            raise ValueError(
                "Invalid value for `action_for_contacts` ({0}), must be one of {1}"  # noqa: E501
                .format(action_for_contacts, allowed_values)
            )

        self._action_for_contacts = action_for_contacts

    @property
    def action_for_email_campaigns(self):
        """Gets the action_for_email_campaigns of this RequestContactExportCustomContactFilter.  # noqa: E501

        Mandatory if neither actionForContacts nor actionForSmsCampaigns is passed. This will export the contacts on the basis of provided action applied on email campaigns. * openers & nonOpeners - emailCampaignId is mandatory. Fetch the list of readers / non-readers for a particular email campaign. * clickers & nonClickers - emailCampaignId is mandatory. Fetch the list of clickers / non-clickers for a particular email campaign. * unsubscribed - emailCampaignId is mandatory. Fetch the list of all unsubscribed (blacklisted via any means) contacts for a particular email campaign. * hardBounces & softBounces - emailCampaignId is optional. Fetch the list of hard bounces / soft bounces for a particular / all email campaign(s).   # noqa: E501

        :return: The action_for_email_campaigns of this RequestContactExportCustomContactFilter.  # noqa: E501
        :rtype: str
        """
        return self._action_for_email_campaigns

    @action_for_email_campaigns.setter
    def action_for_email_campaigns(self, action_for_email_campaigns):
        """Sets the action_for_email_campaigns of this RequestContactExportCustomContactFilter.

        Mandatory if neither actionForContacts nor actionForSmsCampaigns is passed. This will export the contacts on the basis of provided action applied on email campaigns. * openers & nonOpeners - emailCampaignId is mandatory. Fetch the list of readers / non-readers for a particular email campaign. * clickers & nonClickers - emailCampaignId is mandatory. Fetch the list of clickers / non-clickers for a particular email campaign. * unsubscribed - emailCampaignId is mandatory. Fetch the list of all unsubscribed (blacklisted via any means) contacts for a particular email campaign. * hardBounces & softBounces - emailCampaignId is optional. Fetch the list of hard bounces / soft bounces for a particular / all email campaign(s).   # noqa: E501

        :param action_for_email_campaigns: The action_for_email_campaigns of this RequestContactExportCustomContactFilter.  # noqa: E501
        :type: str
        """
        allowed_values = ["openers", "nonOpeners", "clickers", "nonClickers", "unsubscribed", "hardBounces", "softBounces"]  # noqa: E501
        if action_for_email_campaigns not in allowed_values:
            raise ValueError(
                "Invalid value for `action_for_email_campaigns` ({0}), must be one of {1}"  # noqa: E501
                .format(action_for_email_campaigns, allowed_values)
            )

        self._action_for_email_campaigns = action_for_email_campaigns

    @property
    def action_for_sms_campaigns(self):
        """Gets the action_for_sms_campaigns of this RequestContactExportCustomContactFilter.  # noqa: E501

        Mandatory if neither actionForContacts nor actionForEmailCampaigns is passed. This will export the contacts on the basis of provided action applied on sms campaigns. * unsubscribed - Fetch the list of all unsubscribed (blacklisted via any means) contacts for all / particular sms campaigns. * hardBounces & softBounces - Fetch the list of hard bounces / soft bounces for all / particular sms campaigns.   # noqa: E501

        :return: The action_for_sms_campaigns of this RequestContactExportCustomContactFilter.  # noqa: E501
        :rtype: str
        """
        return self._action_for_sms_campaigns

    @action_for_sms_campaigns.setter
    def action_for_sms_campaigns(self, action_for_sms_campaigns):
        """Sets the action_for_sms_campaigns of this RequestContactExportCustomContactFilter.

        Mandatory if neither actionForContacts nor actionForEmailCampaigns is passed. This will export the contacts on the basis of provided action applied on sms campaigns. * unsubscribed - Fetch the list of all unsubscribed (blacklisted via any means) contacts for all / particular sms campaigns. * hardBounces & softBounces - Fetch the list of hard bounces / soft bounces for all / particular sms campaigns.   # noqa: E501

        :param action_for_sms_campaigns: The action_for_sms_campaigns of this RequestContactExportCustomContactFilter.  # noqa: E501
        :type: str
        """
        allowed_values = ["hardBounces", "softBounces", "unsubscribed"]  # noqa: E501
        if action_for_sms_campaigns not in allowed_values:
            raise ValueError(
                "Invalid value for `action_for_sms_campaigns` ({0}), must be one of {1}"  # noqa: E501
                .format(action_for_sms_campaigns, allowed_values)
            )

        self._action_for_sms_campaigns = action_for_sms_campaigns

    @property
    def list_id(self):
        """Gets the list_id of this RequestContactExportCustomContactFilter.  # noqa: E501

        Mandatory if actionForContacts is passed, ignored otherwise. Id of the list for which the corresponding action shall be applied in the filter.  # noqa: E501

        :return: The list_id of this RequestContactExportCustomContactFilter.  # noqa: E501
        :rtype: int
        """
        return self._list_id

    @list_id.setter
    def list_id(self, list_id):
        """Sets the list_id of this RequestContactExportCustomContactFilter.

        Mandatory if actionForContacts is passed, ignored otherwise. Id of the list for which the corresponding action shall be applied in the filter.  # noqa: E501

        :param list_id: The list_id of this RequestContactExportCustomContactFilter.  # noqa: E501
        :type: int
        """

        self._list_id = list_id

    @property
    def email_campaign_id(self):
        """Gets the email_campaign_id of this RequestContactExportCustomContactFilter.  # noqa: E501

        Considered only if actionForEmailCampaigns is passed, ignored otherwise. Mandatory if action is one of the following - openers, nonOpeners, clickers, nonClickers, unsubscribed. The id of the email campaign for which the corresponding action shall be applied in the filter.  # noqa: E501

        :return: The email_campaign_id of this RequestContactExportCustomContactFilter.  # noqa: E501
        :rtype: int
        """
        return self._email_campaign_id

    @email_campaign_id.setter
    def email_campaign_id(self, email_campaign_id):
        """Sets the email_campaign_id of this RequestContactExportCustomContactFilter.

        Considered only if actionForEmailCampaigns is passed, ignored otherwise. Mandatory if action is one of the following - openers, nonOpeners, clickers, nonClickers, unsubscribed. The id of the email campaign for which the corresponding action shall be applied in the filter.  # noqa: E501

        :param email_campaign_id: The email_campaign_id of this RequestContactExportCustomContactFilter.  # noqa: E501
        :type: int
        """

        self._email_campaign_id = email_campaign_id

    @property
    def sms_campaign_id(self):
        """Gets the sms_campaign_id of this RequestContactExportCustomContactFilter.  # noqa: E501

        Considered only if actionForSmsCampaigns is passed, ignored otherwise. The id of sms campaign for which the corresponding action shall be applied in the filter.  # noqa: E501

        :return: The sms_campaign_id of this RequestContactExportCustomContactFilter.  # noqa: E501
        :rtype: int
        """
        return self._sms_campaign_id

    @sms_campaign_id.setter
    def sms_campaign_id(self, sms_campaign_id):
        """Sets the sms_campaign_id of this RequestContactExportCustomContactFilter.

        Considered only if actionForSmsCampaigns is passed, ignored otherwise. The id of sms campaign for which the corresponding action shall be applied in the filter.  # noqa: E501

        :param sms_campaign_id: The sms_campaign_id of this RequestContactExportCustomContactFilter.  # noqa: E501
        :type: int
        """

        self._sms_campaign_id = sms_campaign_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RequestContactExportCustomContactFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestContactExportCustomContactFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RequestContactImport(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_url': 'str',
        'file_body': 'str',
        'list_ids': 'list[int]',
        'notify_url': 'str',
        'new_list': 'RequestContactImportNewList',
        'email_blacklist': 'bool',
        'sms_blacklist': 'bool',
        'update_existing_contacts': 'bool',
        'empty_contacts_attributes': 'bool'
    }

    attribute_map = {
        'file_url': 'fileUrl',
        'file_body': 'fileBody',
        'list_ids': 'listIds',
        'notify_url': 'notifyUrl',
        'new_list': 'newList',
        'email_blacklist': 'emailBlacklist',
        'sms_blacklist': 'smsBlacklist',
        'update_existing_contacts': 'updateExistingContacts',
        'empty_contacts_attributes': 'emptyContactsAttributes'
    }

    def __init__(self, file_url=None, file_body=None, list_ids=None, notify_url=None, new_list=None, email_blacklist=False, sms_blacklist=False, update_existing_contacts=True, empty_contacts_attributes=False):  # noqa: E501
        """RequestContactImport - a model defined in Swagger"""  # noqa: E501

        self._file_url = None
        self._file_body = None
        self._list_ids = None
        self._notify_url = None
        self._new_list = None
        self._email_blacklist = None
        self._sms_blacklist = None
        self._update_existing_contacts = None
        self._empty_contacts_attributes = None
        self.discriminator = None

        if file_url is not None:
            self.file_url = file_url
        if file_body is not None:
            self.file_body = file_body
        if list_ids is not None:
            self.list_ids = list_ids
        if notify_url is not None:
            self.notify_url = notify_url
        if new_list is not None:
            self.new_list = new_list
        if email_blacklist is not None:
            self.email_blacklist = email_blacklist
        if sms_blacklist is not None:
            self.sms_blacklist = sms_blacklist
        if update_existing_contacts is not None:
            self.update_existing_contacts = update_existing_contacts
        if empty_contacts_attributes is not None:
            self.empty_contacts_attributes = empty_contacts_attributes

    @property
    def file_url(self):
        """Gets the file_url of this RequestContactImport.  # noqa: E501

        Mandatory if fileBody is not defined. URL of the file to be imported (no local file). Possible file formats: .txt, .csv  # noqa: E501

        :return: The file_url of this RequestContactImport.  # noqa: E501
        :rtype: str
        """
        return self._file_url

    @file_url.setter
    def file_url(self, file_url):
        """Sets the file_url of this RequestContactImport.

        Mandatory if fileBody is not defined. URL of the file to be imported (no local file). Possible file formats: .txt, .csv  # noqa: E501

        :param file_url: The file_url of this RequestContactImport.  # noqa: E501
        :type: str
        """

        self._file_url = file_url

    @property
    def file_body(self):
        """Gets the file_body of this RequestContactImport.  # noqa: E501

        Mandatory if fileUrl is not defined. CSV content to be imported. Use semicolon to separate multiple attributes  # noqa: E501

        :return: The file_body of this RequestContactImport.  # noqa: E501
        :rtype: str
        """
        return self._file_body

    @file_body.setter
    def file_body(self, file_body):
        """Sets the file_body of this RequestContactImport.

        Mandatory if fileUrl is not defined. CSV content to be imported. Use semicolon to separate multiple attributes  # noqa: E501

        :param file_body: The file_body of this RequestContactImport.  # noqa: E501
        :type: str
        """

        self._file_body = file_body

    @property
    def list_ids(self):
        """Gets the list_ids of this RequestContactImport.  # noqa: E501

        Mandatory if newList is not defined. Ids of the lists in which the contacts shall be imported. For example, [2, 4, 7].  # noqa: E501

        :return: The list_ids of this RequestContactImport.  # noqa: E501
        :rtype: list[int]
        """
        return self._list_ids

    @list_ids.setter
    def list_ids(self, list_ids):
        """Sets the list_ids of this RequestContactImport.

        Mandatory if newList is not defined. Ids of the lists in which the contacts shall be imported. For example, [2, 4, 7].  # noqa: E501

        :param list_ids: The list_ids of this RequestContactImport.  # noqa: E501
        :type: list[int]
        """

        self._list_ids = list_ids

    @property
    def notify_url(self):
        """Gets the notify_url of this RequestContactImport.  # noqa: E501

        URL that will be called once the export process is finished  # noqa: E501

        :return: The notify_url of this RequestContactImport.  # noqa: E501
        :rtype: str
        """
        return self._notify_url

    @notify_url.setter
    def notify_url(self, notify_url):
        """Sets the notify_url of this RequestContactImport.

        URL that will be called once the export process is finished  # noqa: E501

        :param notify_url: The notify_url of this RequestContactImport.  # noqa: E501
        :type: str
        """

        self._notify_url = notify_url

    @property
    def new_list(self):
        """Gets the new_list of this RequestContactImport.  # noqa: E501


        :return: The new_list of this RequestContactImport.  # noqa: E501
        :rtype: RequestContactImportNewList
        """
        return self._new_list

    @new_list.setter
    def new_list(self, new_list):
        """Sets the new_list of this RequestContactImport.


        :param new_list: The new_list of this RequestContactImport.  # noqa: E501
        :type: RequestContactImportNewList
        """

        self._new_list = new_list

    @property
    def email_blacklist(self):
        """Gets the email_blacklist of this RequestContactImport.  # noqa: E501

        To blacklist all the contacts for email  # noqa: E501

        :return: The email_blacklist of this RequestContactImport.  # noqa: E501
        :rtype: bool
        """
        return self._email_blacklist

    @email_blacklist.setter
    def email_blacklist(self, email_blacklist):
        """Sets the email_blacklist of this RequestContactImport.

        To blacklist all the contacts for email  # noqa: E501

        :param email_blacklist: The email_blacklist of this RequestContactImport.  # noqa: E501
        :type: bool
        """

        self._email_blacklist = email_blacklist

    @property
    def sms_blacklist(self):
        """Gets the sms_blacklist of this RequestContactImport.  # noqa: E501

        To blacklist all the contacts for sms  # noqa: E501

        :return: The sms_blacklist of this RequestContactImport.  # noqa: E501
        :rtype: bool
        """
        return self._sms_blacklist

    @sms_blacklist.setter
    def sms_blacklist(self, sms_blacklist):
        """Sets the sms_blacklist of this RequestContactImport.

        To blacklist all the contacts for sms  # noqa: E501

        :param sms_blacklist: The sms_blacklist of this RequestContactImport.  # noqa: E501
        :type: bool
        """

        self._sms_blacklist = sms_blacklist

    @property
    def update_existing_contacts(self):
        """Gets the update_existing_contacts of this RequestContactImport.  # noqa: E501

        To facilitate the choice to update the existing contacts  # noqa: E501

        :return: The update_existing_contacts of this RequestContactImport.  # noqa: E501
        :rtype: bool
        """
        return self._update_existing_contacts

    @update_existing_contacts.setter
    def update_existing_contacts(self, update_existing_contacts):
        """Sets the update_existing_contacts of this RequestContactImport.

        To facilitate the choice to update the existing contacts  # noqa: E501

        :param update_existing_contacts: The update_existing_contacts of this RequestContactImport.  # noqa: E501
        :type: bool
        """

        self._update_existing_contacts = update_existing_contacts

    @property
    def empty_contacts_attributes(self):
        """Gets the empty_contacts_attributes of this RequestContactImport.  # noqa: E501

        To facilitate the choice to erase any attribute of the existing contacts with empty value. emptyContactsAttributes = true means the empty fields in your import will erase any attribute that currently contain data in SendinBlue, & emptyContactsAttributes = false means the empty fields will not affect your existing data ( only available if `updateExistingContacts` set to true )  # noqa: E501

        :return: The empty_contacts_attributes of this RequestContactImport.  # noqa: E501
        :rtype: bool
        """
        return self._empty_contacts_attributes

    @empty_contacts_attributes.setter
    def empty_contacts_attributes(self, empty_contacts_attributes):
        """Sets the empty_contacts_attributes of this RequestContactImport.

        To facilitate the choice to erase any attribute of the existing contacts with empty value. emptyContactsAttributes = true means the empty fields in your import will erase any attribute that currently contain data in SendinBlue, & emptyContactsAttributes = false means the empty fields will not affect your existing data ( only available if `updateExistingContacts` set to true )  # noqa: E501

        :param empty_contacts_attributes: The empty_contacts_attributes of this RequestContactImport.  # noqa: E501
        :type: bool
        """

        self._empty_contacts_attributes = empty_contacts_attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RequestContactImport, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestContactImport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RequestContactExport(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'export_attributes': 'list[str]',
        'contact_filter': 'object',
        'custom_contact_filter': 'RequestContactExportCustomContactFilter',
        'notify_url': 'str'
    }

    attribute_map = {
        'export_attributes': 'exportAttributes',
        'contact_filter': 'contactFilter',
        'custom_contact_filter': 'customContactFilter',
        'notify_url': 'notifyUrl'
    }

    def __init__(self, export_attributes=None, contact_filter=None, custom_contact_filter=None, notify_url=None):  # noqa: E501
        """RequestContactExport - a model defined in Swagger"""  # noqa: E501

        self._export_attributes = None
        self._contact_filter = None
        self._custom_contact_filter = None
        self._notify_url = None
        self.discriminator = None

        if export_attributes is not None:
            self.export_attributes = export_attributes
        if contact_filter is not None:
            self.contact_filter = contact_filter
        if custom_contact_filter is not None:
            self.custom_contact_filter = custom_contact_filter
        if notify_url is not None:
            self.notify_url = notify_url

    @property
    def export_attributes(self):
        """Gets the export_attributes of this RequestContactExport.  # noqa: E501

        List of all the attributes that you want to export. These attributes must be present in your contact database. For example, ['fname', 'lname', 'email'].  # noqa: E501

        :return: The export_attributes of this RequestContactExport.  # noqa: E501
        :rtype: list[str]
        """
        return self._export_attributes

    @export_attributes.setter
    def export_attributes(self, export_attributes):
        """Sets the export_attributes of this RequestContactExport.

        List of all the attributes that you want to export. These attributes must be present in your contact database. For example, ['fname', 'lname', 'email'].  # noqa: E501

        :param export_attributes: The export_attributes of this RequestContactExport.  # noqa: E501
        :type: list[str]
        """

        self._export_attributes = export_attributes

    @property
    def contact_filter(self):
        """Gets the contact_filter of this RequestContactExport.  # noqa: E501

        This attribute has been deprecated and will be removed by January 1st, 2021. Only one of the two filter options (contactFilter or customContactFilter) can be passed in the request. Set the filter for the contacts to be exported. For example, {'blacklisted':true} will export all the blacklisted contacts.   # noqa: E501

        :return: The contact_filter of this RequestContactExport.  # noqa: E501
        :rtype: object
        """
        return self._contact_filter

    @contact_filter.setter
    def contact_filter(self, contact_filter):
        """Sets the contact_filter of this RequestContactExport.

        This attribute has been deprecated and will be removed by January 1st, 2021. Only one of the two filter options (contactFilter or customContactFilter) can be passed in the request. Set the filter for the contacts to be exported. For example, {'blacklisted':true} will export all the blacklisted contacts.   # noqa: E501

        :param contact_filter: The contact_filter of this RequestContactExport.  # noqa: E501
        :type: object
        """

        self._contact_filter = contact_filter

    @property
    def custom_contact_filter(self):
        """Gets the custom_contact_filter of this RequestContactExport.  # noqa: E501


        :return: The custom_contact_filter of this RequestContactExport.  # noqa: E501
        :rtype: RequestContactExportCustomContactFilter
        """
        return self._custom_contact_filter

    @custom_contact_filter.setter
    def custom_contact_filter(self, custom_contact_filter):
        """Sets the custom_contact_filter of this RequestContactExport.


        :param custom_contact_filter: The custom_contact_filter of this RequestContactExport.  # noqa: E501
        :type: RequestContactExportCustomContactFilter
        """

        self._custom_contact_filter = custom_contact_filter

    @property
    def notify_url(self):
        """Gets the notify_url of this RequestContactExport.  # noqa: E501

        Webhook that will be called once the export process is finished  # noqa: E501

        :return: The notify_url of this RequestContactExport.  # noqa: E501
        :rtype: str
        """
        return self._notify_url

    @notify_url.setter
    def notify_url(self, notify_url):
        """Sets the notify_url of this RequestContactExport.

        Webhook that will be called once the export process is finished  # noqa: E501

        :param notify_url: The notify_url of this RequestContactExport.  # noqa: E501
        :type: str
        """

        self._notify_url = notify_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RequestContactExport, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestContactExport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sib_api_v3_sdk
from sib_api_v3_sdk.api.sms_campaigns_api import SMSCampaignsApi  # noqa: E501
from sib_api_v3_sdk.rest import ApiException


class TestSMSCampaignsApi(unittest.TestCase):
    """SMSCampaignsApi unit test stubs"""

    def setUp(self):
        self.api = sib_api_v3_sdk.api.sms_campaigns_api.SMSCampaignsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_sms_campaign(self):
        """Test case for create_sms_campaign

        Creates an SMS campaign  # noqa: E501
        """
        pass

    def test_delete_sms_campaign(self):
        """Test case for delete_sms_campaign

        Delete the SMS campaign  # noqa: E501
        """
        pass

    def test_get_sms_campaign(self):
        """Test case for get_sms_campaign

        Get an SMS campaign  # noqa: E501
        """
        pass

    def test_get_sms_campaigns(self):
        """Test case for get_sms_campaigns

        Returns the informations for all your created SMS campaigns  # noqa: E501
        """
        pass

    def test_request_sms_recipient_export(self):
        """Test case for request_sms_recipient_export

        Exports the recipients of the specified campaign.  # noqa: E501
        """
        pass

    def test_send_sms_campaign_now(self):
        """Test case for send_sms_campaign_now

        Send your SMS campaign immediately  # noqa: E501
        """
        pass

    def test_send_sms_report(self):
        """Test case for send_sms_report

        Send report of SMS campaigns  # noqa: E501
        """
        pass

    def test_send_test_sms(self):
        """Test case for send_test_sms

        Send an SMS  # noqa: E501
        """
        pass

    def test_update_sms_campaign(self):
        """Test case for update_sms_campaign

        Updates an SMS campaign  # noqa: E501
        """
        pass

    def test_update_sms_campaign_status(self):
        """Test case for update_sms_campaign_status

        Update the campaign status  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   | 406  | Error. Not Acceptable  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class UpdateSmtpTemplate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tag': 'str',
        'sender': 'UpdateSmtpTemplateSender',
        'template_name': 'str',
        'html_content': 'str',
        'html_url': 'str',
        'subject': 'str',
        'reply_to': 'str',
        'to_field': 'str',
        'attachment_url': 'str',
        'is_active': 'bool'
    }

    attribute_map = {
        'tag': 'tag',
        'sender': 'sender',
        'template_name': 'templateName',
        'html_content': 'htmlContent',
        'html_url': 'htmlUrl',
        'subject': 'subject',
        'reply_to': 'replyTo',
        'to_field': 'toField',
        'attachment_url': 'attachmentUrl',
        'is_active': 'isActive'
    }

    def __init__(self, tag=None, sender=None, template_name=None, html_content=None, html_url=None, subject=None, reply_to=None, to_field=None, attachment_url=None, is_active=None):  # noqa: E501
        """UpdateSmtpTemplate - a model defined in Swagger"""  # noqa: E501

        self._tag = None
        self._sender = None
        self._template_name = None
        self._html_content = None
        self._html_url = None
        self._subject = None
        self._reply_to = None
        self._to_field = None
        self._attachment_url = None
        self._is_active = None
        self.discriminator = None

        if tag is not None:
            self.tag = tag
        if sender is not None:
            self.sender = sender
        if template_name is not None:
            self.template_name = template_name
        if html_content is not None:
            self.html_content = html_content
        if html_url is not None:
            self.html_url = html_url
        if subject is not None:
            self.subject = subject
        if reply_to is not None:
            self.reply_to = reply_to
        if to_field is not None:
            self.to_field = to_field
        if attachment_url is not None:
            self.attachment_url = attachment_url
        if is_active is not None:
            self.is_active = is_active

    @property
    def tag(self):
        """Gets the tag of this UpdateSmtpTemplate.  # noqa: E501

        Tag of the template  # noqa: E501

        :return: The tag of this UpdateSmtpTemplate.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this UpdateSmtpTemplate.

        Tag of the template  # noqa: E501

        :param tag: The tag of this UpdateSmtpTemplate.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def sender(self):
        """Gets the sender of this UpdateSmtpTemplate.  # noqa: E501


        :return: The sender of this UpdateSmtpTemplate.  # noqa: E501
        :rtype: UpdateSmtpTemplateSender
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this UpdateSmtpTemplate.


        :param sender: The sender of this UpdateSmtpTemplate.  # noqa: E501
        :type: UpdateSmtpTemplateSender
        """

        self._sender = sender

    @property
    def template_name(self):
        """Gets the template_name of this UpdateSmtpTemplate.  # noqa: E501

        Name of the template  # noqa: E501

        :return: The template_name of this UpdateSmtpTemplate.  # noqa: E501
        :rtype: str
        """
        return self._template_name

    @template_name.setter
    def template_name(self, template_name):
        """Sets the template_name of this UpdateSmtpTemplate.

        Name of the template  # noqa: E501

        :param template_name: The template_name of this UpdateSmtpTemplate.  # noqa: E501
        :type: str
        """

        self._template_name = template_name

    @property
    def html_content(self):
        """Gets the html_content of this UpdateSmtpTemplate.  # noqa: E501

        Required if htmlUrl is empty. Body of the message (HTML must have more than 10 characters)  # noqa: E501

        :return: The html_content of this UpdateSmtpTemplate.  # noqa: E501
        :rtype: str
        """
        return self._html_content

    @html_content.setter
    def html_content(self, html_content):
        """Sets the html_content of this UpdateSmtpTemplate.

        Required if htmlUrl is empty. Body of the message (HTML must have more than 10 characters)  # noqa: E501

        :param html_content: The html_content of this UpdateSmtpTemplate.  # noqa: E501
        :type: str
        """

        self._html_content = html_content

    @property
    def html_url(self):
        """Gets the html_url of this UpdateSmtpTemplate.  # noqa: E501

        Required if htmlContent is empty. URL to the body of the email (HTML)  # noqa: E501

        :return: The html_url of this UpdateSmtpTemplate.  # noqa: E501
        :rtype: str
        """
        return self._html_url

    @html_url.setter
    def html_url(self, html_url):
        """Sets the html_url of this UpdateSmtpTemplate.

        Required if htmlContent is empty. URL to the body of the email (HTML)  # noqa: E501

        :param html_url: The html_url of this UpdateSmtpTemplate.  # noqa: E501
        :type: str
        """

        self._html_url = html_url

    @property
    def subject(self):
        """Gets the subject of this UpdateSmtpTemplate.  # noqa: E501

        Subject of the email  # noqa: E501

        :return: The subject of this UpdateSmtpTemplate.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this UpdateSmtpTemplate.

        Subject of the email  # noqa: E501

        :param subject: The subject of this UpdateSmtpTemplate.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def reply_to(self):
        """Gets the reply_to of this UpdateSmtpTemplate.  # noqa: E501

        Email on which campaign recipients will be able to reply to  # noqa: E501

        :return: The reply_to of this UpdateSmtpTemplate.  # noqa: E501
        :rtype: str
        """
        return self._reply_to

    @reply_to.setter
    def reply_to(self, reply_to):
        """Sets the reply_to of this UpdateSmtpTemplate.

        Email on which campaign recipients will be able to reply to  # noqa: E501

        :param reply_to: The reply_to of this UpdateSmtpTemplate.  # noqa: E501
        :type: str
        """

        self._reply_to = reply_to

    @property
    def to_field(self):
        """Gets the to_field of this UpdateSmtpTemplate.  # noqa: E501

        To personalize the «To» Field. If you want to include the first name and last name of your recipient, add {FNAME} {LNAME}. These contact attributes must already exist in your SendinBlue account. If input parameter 'params' used please use {{contact.FNAME}} {{contact.LNAME}} for personalization  # noqa: E501

        :return: The to_field of this UpdateSmtpTemplate.  # noqa: E501
        :rtype: str
        """
        return self._to_field

    @to_field.setter
    def to_field(self, to_field):
        """Sets the to_field of this UpdateSmtpTemplate.

        To personalize the «To» Field. If you want to include the first name and last name of your recipient, add {FNAME} {LNAME}. These contact attributes must already exist in your SendinBlue account. If input parameter 'params' used please use {{contact.FNAME}} {{contact.LNAME}} for personalization  # noqa: E501

        :param to_field: The to_field of this UpdateSmtpTemplate.  # noqa: E501
        :type: str
        """

        self._to_field = to_field

    @property
    def attachment_url(self):
        """Gets the attachment_url of this UpdateSmtpTemplate.  # noqa: E501

        Absolute url of the attachment (no local file). Extension allowed: xlsx, xls, ods, docx, docm, doc, csv, pdf, txt, gif, jpg, jpeg, png, tif, tiff, rtf, bmp, cgm, css, shtml, html, htm, zip, xml, ppt, pptx, tar, ez, ics, mobi, msg, pub and eps  # noqa: E501

        :return: The attachment_url of this UpdateSmtpTemplate.  # noqa: E501
        :rtype: str
        """
        return self._attachment_url

    @attachment_url.setter
    def attachment_url(self, attachment_url):
        """Sets the attachment_url of this UpdateSmtpTemplate.

        Absolute url of the attachment (no local file). Extension allowed: xlsx, xls, ods, docx, docm, doc, csv, pdf, txt, gif, jpg, jpeg, png, tif, tiff, rtf, bmp, cgm, css, shtml, html, htm, zip, xml, ppt, pptx, tar, ez, ics, mobi, msg, pub and eps  # noqa: E501

        :param attachment_url: The attachment_url of this UpdateSmtpTemplate.  # noqa: E501
        :type: str
        """

        self._attachment_url = attachment_url

    @property
    def is_active(self):
        """Gets the is_active of this UpdateSmtpTemplate.  # noqa: E501

        Status of the template. isActive = false means template is inactive, isActive = true means template is active  # noqa: E501

        :return: The is_active of this UpdateSmtpTemplate.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this UpdateSmtpTemplate.

        Status of the template. isActive = false means template is inactive, isActive = true means template is active  # noqa: E501

        :param is_active: The is_active of this UpdateSmtpTemplate.  # noqa: E501
        :type: bool
        """

        self._is_active = is_active

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateSmtpTemplate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSmtpTemplate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
